# List Examples

Examples shipped with `pydykit` can accessed with
`pydykit.examples.ExampleManager`.
This is demonstrated by the list of available examples within the tab `Result` shown below.
The source code generating this list, is shown in tab `Source`.

```python exec="true" source="tabbed-right" html="true"
--8<-- "snippets/list_examples.py"
```
